#ifndef CALCULATOR_H
#define CALCULATOR_H

#include <QWidget>
#include <QStack>
#include <QPushButton>
#include <QGridLayout>
#include <QLCDNumber>
#include <QRegularExpression>
#include <QRadioButton>
#include <QVBoxLayout>
#include <QVector>
#include <QtAlgorithms>
#include <algorithm>
#include <QGroupBox>


class Calculator : public QWidget
{
    Q_OBJECT
private:
QLCDNumber* m_plcd; //pointer on widget of electronic indicator
QStack<QString> m_stk; //stack for performing calculation operations
QString m_strDisplay; //string containing symbols of buttons that user pressed
QRadioButton *regularMode;  //calculator mode
QRadioButton *engineerMode; //calculator mode

//Widgets
QWidget* regularCalcWidget;
QWidget* engineerCalcWidget;
QWidget* topWidget;
QWidget* mainWidget;
QWidget* modesWidget;

//Layouts
QGridLayout* modesLayout;
QGridLayout* regularCalcLayout;
QGridLayout* engineerCalcLayout;
QGridLayout* ptopLayout;
QGridLayout* mainLayout;


private:
    void constructEngineer();
    void constructRegular();
    void constructTopLayout();
    void showRegularCalc();
    void showEngineerCalc();
    int factorial(int);
public:
    Calculator(QWidget* pwgt = 0);
    QPushButton* createButton(const QString& str); //creation of calculator buttons
    int calculate(); //calculation of expressions that are in m_stk

public slots:
    void slotButtonClicked(); //called when one of calculator buttons is pressed
    void slotChangeMode();
};

#endif // CALCULATOR_H
